function im = mean2(im, k)
%MEAN2 performs moving average filtering of an image.
%	Y = MEAN2(IM,K)
% INPUT 
%   IM - Input image
%    K -  KxK filter window. This parameter must be odd. 
% OUTPUT
%   Y -  Output image 

%   Rev 1.0     Oct. 06, 2002   Dmitiry Shutin <dshutin@inw.tugraz.at>
%   Rev 2.0     Oct. 19, 2009   Daniel Arnitz <daniel.arnitz@tugraz.at>
%                               redesign using filter2
%   Rev 2.1     Oct. 30, 2009   added typecast back to original class of input image

% *******************************************************************************************************

if nargin<1
   y=0;
   return;
end
if nargin<2
   k=1;
end
if ( k/2==floor(k/2) )
   warning('Filter length parameter must be odd. K is increased by 1'); %#ok<WNTAG>
   k=k+1;
end

im = feval( class(im), filter2(ones(k,k)/k^2, im, 'same') );


	
	 
